@@ -8,25 +8,24 @@ import os
 import ctypes
 import logging
 import pathlib
-from PySide2.QtWidgets import QApplication
-from PySide2.QtCore import QSettings
+from PySide6.QtWidgets import QApplication
+from PySide6.QtCore import QSettings
 
 from app import module_base
 from app import app_common
 from app import app_gui
 
-import nanosurf.lib.util.fileutil as fileutil
-import nanosurf.lib.datatypes.prop_val as prop_val
+import nanosurf as nsf
 
 dir_name_log = "log"
 dir_name_config = "config"
 dir_name_app = "app"
 dir_name_resources = "app"
 
-class AppSettings(prop_val.PropStore):
-    Logging  = prop_val.PropVal(True)
-    LoadLastSettings = prop_val.PropVal(True)
-    ActiveModuleIndex = prop_val.PropVal(int(0))
+class AppSettings(nsf.PropStore):
+    Logging  = nsf.PropVal(True)
+    LoadLastSettings = nsf.PropVal(True)
+    ActiveModuleIndex = nsf.PropVal(int(0))
 
 class ApplicationBase(QApplication):
     def __init__(self, company: str, app_name_short: str, app_name_long: str,  *args, **kwargs):
@@ -55,8 +54,8 @@ class ApplicationBase(QApplication):
         self.modules = {}
 
     def start_app(self):
-        fileutil.create_folder(self.config_path)
-        prop_val.load_from_ini_file(self.settings, self.config_file, self.config_section)   
+        nsf.util.fileutil.create_folder(self.config_path)
+        nsf.datatypes.prop_val.load_from_ini_file(self.settings, self.config_file, self.config_section)   
         self.setup_logger()
         self.appwindow = app_gui.AppWindow(self)
         self.appwindow.create_gui(self.resource_path / "app_stylesheet.qss", self.resource_path / "app_icon.ico")
@@ -69,7 +68,7 @@ class ApplicationBase(QApplication):
     def quit_app(self):
         self.stop_modules()
         self.do_shutdown()
-        prop_val.save_to_ini_file(self.settings, self.config_file, self.config_section)   
+        nsf.datatypes.prop_val.save_to_ini_file(self.settings, self.config_file, self.config_section)   
 
     def do_startup(self):
         raise NotImplementedError(f"Subclass of '{self.__class__.__name__}' has to implement '{sys._getframe().f_code.co_name}()'")
@@ -78,13 +77,13 @@ class ApplicationBase(QApplication):
         raise NotImplementedError(f"Subclass of '{self.__class__.__name__}' has to implement '{sys._getframe().f_code.co_name}()'")
 
     def save_settings(self, module: module_base.ModuleBase):
-        if isinstance(module.settings, prop_val.PropStore):
-            prop_val.save_to_ini_file(module.settings,self.config_file, module.name)
+        if isinstance(module.settings, nsf.PropStore):
+            nsf.datatypes.prop_val.save_to_ini_file(module.settings,self.config_file, module.name)
  
     def load_settings(self, module: module_base.ModuleBase):
-        if isinstance(module.settings, prop_val.PropStore):
+        if isinstance(module.settings, nsf.PropStore):
             if self.settings.LoadLastSettings.value:
-                prop_val.load_from_ini_file(module.settings, self.config_file, module.name)
+                nsf.datatypes.prop_val.load_from_ini_file(module.settings, self.config_file, module.name)
  
     def setup_logger(self, logfile: pathlib.Path = pathlib.Path("latest.log")):   
         """
@@ -92,7 +91,7 @@ class ApplicationBase(QApplication):
         set up logging to file and choose logger level (from highest level to lowest: Debug, info, warning, error, critical)
         """ 
         if self.settings.Logging.value:
-            fileutil.create_folder(self.log_path)
+            nsf.util.fileutil.create_folder(self.log_path)
             logfilepath = str(self.log_path / logfile) 
             logging.basicConfig(level=logging.DEBUG,
                                 format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s',
@@ -133,5 +132,6 @@ class ApplicationBase(QApplication):
     def activate_debugger_support_for_this_thread(self):
         """ This function has to be called from each new thread to activate debugger support for it"""
         if self.is_in_debugging_mode:
-            import debugpy             
-            debugpy.debug_this_thread()
+            import debugpy
+            debugpy.debug_this_thread()            
+ 
