@@ -3,11 +3,9 @@ Copyright Nanosurf AG 2021
 License - MIT
 """
 
-from PySide2 import QtWidgets
-from PySide2 import QtGui, QtWidgets, QtCore
-from PySide2.QtCore import Qt
-import nanosurf.lib.gui.nsf_info_box as nsf_info_box
-import nanosurf.lib.gui.nsf_colors as nsf_colors
+from PySide6 import QtWidgets
+from PySide6 import QtGui, QtWidgets, QtCore
+import nanosurf as nsf
 from app import app_common, module_base
 
 control_layout_width = 200
@@ -16,7 +14,7 @@ class MenuSeparator(QtWidgets.QFrame):
     def __init__(self, hidden : bool = False, height: int = 1,  **kargs):
         super().__init__(*kargs)
         self.setFrameStyle(QtWidgets.QFrame.HLine | QtWidgets.QFrame.Plain)
-        self.setStyleSheet(f"background-color:#{nsf_colors.NSFColorHexStr.Orange};")
+        self.setStyleSheet(f"background-color:#{nsf.gui.nsf_colors.NSFColorHexStr.Orange};")
         self.setFixedHeight(height)
         self.setHidden(hidden)
 
@@ -32,7 +30,7 @@ class MenuButton(QtWidgets.QWidget):
         self._button.clicked.connect(self._on_clicked)
     
     def set_highlight(self, highlight: bool = False):
-        color = nsf_colors.NSFColorHexStr.Orange if highlight else nsf_colors.NSFColorHexStr.Soft_Gray
+        color = nsf.gui.nsf_colors.NSFColorHexStr.Orange if highlight else nsf.gui.nsf_colors.NSFColorHexStr.Soft_Gray
         self._marker_line.setStyleSheet(f"background-color:#{color};")
 
     def _on_clicked(self):
@@ -71,7 +69,7 @@ class AppWindow(QtWidgets.QMainWindow):
         self.mainScreen = QtWidgets.QWidget()
         self.main_layout = QtWidgets.QVBoxLayout()
         self.main_menu = QtWidgets.QHBoxLayout()
-        self.main_messagebox = nsf_info_box.InfoBox(hidden=True)
+        self.main_messagebox = nsf.gui.NSFInfoBox(hidden=True)
         self.main_stack = QtWidgets.QStackedLayout()
         self.main_stack.addWidget(QtWidgets.QLabel("Main screen"))
 
@@ -89,7 +87,7 @@ class AppWindow(QtWidgets.QMainWindow):
 
     def show_message(self, msg: str, msg_type: app_common.MsgType = app_common.MsgType.Info):
         if msg_type == app_common.MsgType.Error:
-            self.show_info_box(msg, background_color=nsf_colors.NSFColorHexStr.Orange, text_color="")
+            self.show_info_box(msg, background_color=nsf.gui.nsf_colors.NSFColorHexStr.Orange, text_color="")
         elif msg_type == app_common.MsgType.Warn:
             self.show_info_box(msg, '')
         else:
