@@ -4,6 +4,7 @@ License - MIT
 """
 
 import sys
+import PySide6
 import nanosurf as nsf
 
 from app import app_base
@@ -40,5 +41,5 @@ class MyApp(app_base.ApplicationBase):
 if __name__ == "__main__":
     App = MyApp(MyCompany, MyAppNameShort, MyAppNameLong, [])
     App.start_app()
-    sys.exit(App.exec_())
+    sys.exit(App.exec())
 
