@@ -32,7 +32,3 @@ class ChannelD(enum.IntEnum):
     Deflection = 0,
     Topography = 1,
 
-ChannelNames = [
-    'Deflection', 
-    'Topography'
-]
