@@ -4,7 +4,8 @@ License - MIT
 """
 
 import sys
-import nanosurf.lib.datatypes.prop_val as prop_val
+import PySide6
+import nanosurf as nsf
 
 from app import app_base
 from modules.switching_spec_module import module as switching_spec_func
@@ -16,7 +17,7 @@ MyAppNameLong = "Switching spectroscopy application"
 
 class MyAppSettings(app_base.AppSettings):
     """ Settings defined here as PropVal are stored persistently in a ini-file"""
-    AppHelloMsg = prop_val.PropVal(f"Welcome to {MyAppNameLong}")
+    AppHelloMsg = nsf.PropVal(f"Welcome to {MyAppNameLong}")
     
 class MyApp(app_base.ApplicationBase):
     def __init__(self, *args, **kwargs):
@@ -40,5 +41,5 @@ class MyApp(app_base.ApplicationBase):
 if __name__ == "__main__":
     App = MyApp(MyCompany, MyAppNameShort, MyAppNameLong, [])
     App.start_app()
-    sys.exit(App.exec_())
+    sys.exit(App.exec())
 
