@@ -6,7 +6,12 @@ License - MIT
 import sys
 import time
 import logging
-from PySide2.QtCore import QThread, QObject, Signal
+
+from nanosurf.lib.gui.import_helper import import_pyside2_if_none_is_detected
+if import_pyside2_if_none_is_detected():
+    from PySide2.QtCore import QThread, QObject, Signal
+else:
+    from PySide6.QtCore import QThread, QObject, Signal
 
 global_is_in_debugging_mode = (getattr(sys, 'gettrace', lambda : None)() is not None)
 if global_is_in_debugging_mode:
