@@ -4,12 +4,17 @@ License - MIT
 """
 from enum import IntEnum
 import pathlib
-from PySide2 import QtWidgets
+
+from nanosurf.lib.gui.import_helper import import_pyside2_if_none_is_detected
+if import_pyside2_if_none_is_detected():
+   from PySide2 import QtWidgets
+else:
+   from PySide6 import QtWidgets
+
 from nanosurf.lib.gui import nsf_sci_edit, nsf_edit, nsf_combobox
 from nanosurf.lib.datatypes import sci_val
-from nanosurf.lib.datatypes.prop_val import PropVal
 
-def connect_to_property(widget: QtWidgets.QWidget, prop: PropVal) -> bool:
+def connect_to_property(widget: QtWidgets.QWidget, prop: 'nanosurf.lib.datatypes.prop_val.PropVal') -> bool:
    """
    Connect the value of a property to a widgets. Keeps the widget content and the property value in sync
    Note: Not every QWidget can be connected to any Property type. 
