@@ -10,8 +10,14 @@ import typing
 import enum
 import math
 import sys
-from PySide2 import QtGui, QtWidgets
-from PySide2.QtCore import Qt, QTimer, Signal
+
+from nanosurf.lib.gui.import_helper import import_pyside2_if_none_is_detected
+if import_pyside2_if_none_is_detected():
+    from PySide2 import QtGui, QtWidgets
+    from PySide2.QtCore import Qt, QTimer, Signal
+else:
+    from PySide6 import QtGui, QtWidgets
+    from PySide6.QtCore import Qt, QTimer, Signal
 
 import nanosurf.lib.datatypes.sci_val as sci_val
 import nanosurf.lib.datatypes.sci_val.unit_prefix as up
