@@ -354,6 +354,12 @@ class StudioScriptContext(StudioScriptInterface):
         cmd_str = cmd_str.replace("'", "\\'")
         return cmd_str
 
+    def _python_to_lua_list(self, val:str) -> str:
+        if len(val) > 0:
+            if isinstance(val[0], enum.Enum):
+                val = [e.value for e in val]
+        return str(val).removeprefix('[').removesuffix(']')
+    
     def _args_to_string(self, *args) -> str:
         res = ""
         for a in args:
@@ -362,7 +368,7 @@ class StudioScriptContext(StudioScriptInterface):
             elif type(a) == bool:
                 res += str(a).lower()
             elif type(a) == list:
-                res += '{' + str(a).removeprefix('[').removesuffix(']') + '},'
+                res += '{' + self._python_to_lua_list(a) + '},'
             elif isinstance(a, studio_wrapper.CmdTreeNode):
                 res += a._lua_tree_name + ","
             else:
