@@ -66,7 +66,7 @@ class CmdTreeNode():
     def __init__(self):
         self._lua_tree_name = ""
         self._context : 'StudioScriptContext' = None
-        
+
     def __getitem__(self, key):
         return self._context.get(f"{self._lua_tree_name}[{key}]")
 
@@ -89,11 +89,11 @@ class CmdTreeCompiler():
         self._file_content = [""]
         self._last_error = ""
         self.my_own_path = pathlib.Path(os.path.dirname(os.path.abspath(__file__)))
-        self.regex_non_enum_chars = re.compile('[^0-9a-zA-Z]+', flags=re.UNICODE); 
-        self.regex_first_char_a_number = re.compile('\d\w*', flags=re.UNICODE); 
+        self.regex_non_enum_chars = re.compile('[^0-9a-zA-Z]+', flags=re.UNICODE);
+        self.regex_first_char_a_number = re.compile('\d\w*', flags=re.UNICODE);
 
     def build_wrapper_class(self, context_name: str, cmd_table) -> bool:
-        self.cmd_package_name = g_context_package_name_prefix + context_name 
+        self.cmd_package_name = g_context_package_name_prefix + context_name
 
         # check if recompilation of command tree is necessary
         runtime_cmd_tree_hash = self.get_table_version(cmd_table, g_cmd_tree_root_name)
@@ -135,14 +135,14 @@ class CmdTreeCompiler():
     def _get_table_hash_str(self, table, lua_tree_name: str) -> str:
         hash_str = lua_tree_name
         for item_name, item_value in table.items():
-            item_type = get_lua_type(item_value) 
-            if item_type == LuaType.Table:
+            item_type = get_lua_type(item_value)
+            if (item_type == LuaType.Table) and type(item_name) == str: # Ignore arrays with numeric index
                 new_lua_tree_name = str(lua_tree_name+"."+item_name)
                 hash_str += str(";" + self._get_table_hash_str(item_value, new_lua_tree_name))
             elif (item_type != LuaType.Nil) and type(item_name) == str:
                 new_lua_tree_name = str(lua_tree_name+"."+item_name)
                 hash_str += str(";" + new_lua_tree_name)
-        return hash_str 
+        return hash_str
 
     def _has_table_functions(self, table) -> bool:
         for _, item_value in table.items():
@@ -151,7 +151,7 @@ class CmdTreeCompiler():
         return False
 
     def _is_lu_trigger_func(sel, tree_name:str) -> bool:
-        try: 
+        try:
             prefix = tree_name[:7]
             suffix = tree_name[-8:]
             return prefix == "root.lu" and suffix == ".trigger"
@@ -159,7 +159,7 @@ class CmdTreeCompiler():
             return False
 
     def _is_lu_busy_func(sel, tree_name:str) -> bool:
-        try: 
+        try:
             prefix = tree_name[:7]
             suffix = tree_name[-5:]
             return prefix == "root.lu" and suffix == ".busy"
@@ -176,7 +176,7 @@ class CmdTreeCompiler():
 
     def _is_table_a_studio_property(self, table) -> bool:
         """ Detect if a lua table contains a studio property definition
-        
+
         Implementation
         --------------
         This detection method is coupled with the studio lua script "make_property.lua"
@@ -189,7 +189,7 @@ class CmdTreeCompiler():
         # search for key word
         for item_name, _ in table.items():
             if item_name == "value" or item_name == "vector":
-                found_value = True  
+                found_value = True
                 break
 
         # if key word found check for accessor function
@@ -201,14 +201,14 @@ class CmdTreeCompiler():
                     break
 
         # if key value and accessor found, it is a property definition
-        return found_access_func and found_value 
+        return found_access_func and found_value
 
     def _is_enum_property(self, prop_elements:dict[str, str]) -> bool:
         return "enum" in prop_elements
-        
+
     def _is_vector_property(self, prop_elements:dict[str, str]) -> bool:
         return "vector" in prop_elements
-        
+
     def _is_power_of_two(self, n:int):
         return (n != 0) and (n & (n-1) == 0)
 
@@ -217,7 +217,7 @@ class CmdTreeCompiler():
         for item_name, item_value in enum_table.items():
             if item_name != "all" and not(item_name == "none" and item_value == 0):
                 has_only_bitmask &= self._is_power_of_two(int(item_value))
-                if has_only_bitmask == False: 
+                if has_only_bitmask == False:
                     break
         return has_only_bitmask
 
@@ -236,7 +236,7 @@ class CmdTreeCompiler():
             return LuaType.Float
         elif type_str == "integer":
             return LuaType.Int
-        return LuaType.Nil        
+        return LuaType.Nil
 
     def _get_studio_property_elements(self, prop_table, lua_tree_name : str) -> dict[str, str]:
         """ Extract from property style lua_table a list of all property names and their types
@@ -270,11 +270,11 @@ class CmdTreeCompiler():
 
         # write content to file
         try:
-            f =  open(python_file, "w")    
+            f =  open(python_file, "w")
         except:
             self._last_error = "Could not create file: '{python_file}'"
             return done
-        
+
         try:
             for l in self._file_content:
                 f.write(l)
@@ -300,7 +300,7 @@ class CmdTreeCompiler():
                 self._dump_command_table(item_value, indent + "   "  )
 
     def write_header(self, table_version_hash: str, compiler_version: str):
-        class_list = [] 
+        class_list = []
         class_list.append(f"# studio_wrapper.py\n")
         class_list.append(f"\n")
         class_list.append(f"import enum\n")
@@ -310,7 +310,7 @@ class CmdTreeCompiler():
         class_list.append(f"g_cmd_tree_hash = '{table_version_hash}'\n")
         class_list.append(f"g_compiler_version = '{compiler_version}'\n")
         class_list.append(f"\n")
-        
+
         self._file_content = class_list + self._file_content
 
     def _write_cmd_tree_node(self, table, class_name:str, lua_tree_name: str) -> list[str]:
@@ -344,7 +344,7 @@ class CmdTreeCompiler():
             class_list.append("\n")
 
             for value_name, value_type in prop_elements.items():
-                if value_name == "value": 
+                if value_name == "value":
                     if is_enum_type:
                         if is_enum_mask_type:
                             class_list.append(f"    @property\n")
@@ -355,7 +355,7 @@ class CmdTreeCompiler():
                             class_list.append(f"    def {value_name}(self, new_val:int):\n")
                             class_list.append(f"        self._context.set('{lua_tree_name}.value_raw', int(new_val))\n")
                             class_list.append("\n")
-                        else:                        
+                        else:
                             class_list.append(f"    @property\n")
                             class_list.append(f"    def {value_name}(self) -> ValueEnum:\n")
                             class_list.append(f"        return {class_name}.ValueEnum(self._context.get('{lua_tree_name}.value_raw'))\n")
@@ -407,6 +407,8 @@ class CmdTreeCompiler():
                 if item_type == LuaType.Table:
                     if (class_name == "Root") and (item_name == "seq") and g_skip_sequencer_definition:
                         continue
+                    if (type(item_name) != str): # Ignore arrays with numeric index
+                        continue
                     class_list.append(f"        self.{item_name} = {class_name+item_name.capitalize()}(self._context)\n")
             class_list.append(f"\n")
 
@@ -437,7 +439,7 @@ class CmdTreeCompiler():
                     class_list.append(f"    @{item_name}.setter\n")
                     class_list.append(f"    def {item_name}(self, new_val:{type_str}):\n")
                     class_list.append(f"        self._context.set('{lua_tree_name}.{item_name}', {type_str}(new_val))\n")
-                    class_list.append("\n")        
+                    class_list.append("\n")
 
             class_list.append("\n")
 
@@ -447,12 +449,12 @@ class CmdTreeCompiler():
             # follow cmd_tree nodes recursively
             for item_name, item_value in table.items():
                 item_type = get_lua_type(item_value)
-                if item_type == LuaType.Table:
+                if (item_type == LuaType.Table) and type(item_name) == str: # Ignore arrays with numeric index
                     new_class_name = str(class_name+item_name.capitalize())
                     new_lua_tree_name = str(lua_tree_name+"."+item_name)
 
-                    # currently we skip sequencer definition 
+                    # currently we skip sequencer definition
                     if new_lua_tree_name == "root.seq" and g_skip_sequencer_definition:
                         continue
-                    
+
                     self._write_cmd_tree_node(item_value, new_class_name, new_lua_tree_name)
