@@ -1,3 +1,3 @@
-"""Package for scripting the Nansurf control software.
+"""Package for scripting the Nanosurf control software.
 Copyright (C) Nanosurf AG - All Rights Reserved (2021)
 License - MIT"""
\ No newline at end of file
