@@ -289,56 +289,59 @@ class _ModZControlOutput(_ModulationOutput):
             self._pid_control.select_sweep.value = self._old_value
         super().__del__()
 
-class FrequencySweepOutput(enum.Enum):
+class FrequencySweepOutput(enum.IntEnum):
     """Enumeration for the modulation output selection"""
-    Normal_Excitation = enum.auto(),
-    FastUser_OutB = enum.auto(),
-    TipVoltage_UserOutA = enum.auto(),
-    UserOut1_UserC = enum.auto(),
-    UserOut2_UserA = enum.auto(),
-    UserOut3_Monitor1 = enum.auto(),
-    UserOut4_Monitor2 = enum.auto(),
-    PositionX = enum.auto(),
-    PositionY = enum.auto(),
-    PositionZ = enum.auto(),
-    ModOutZ = enum.auto(),
-    ModXControlSet = enum.auto(),
-    ModYControlSet = enum.auto(),
-    ModZControlSet = enum.auto(),
-    ModZControlOutput = enum.auto()
+    Normal_Excitation = 0
+    FastUser_OutB = 1 
+    TipVoltage_UserOutA = 2
+    UserOut1_UserC = 3
+    UserOut2_UserA = 4
+    UserOut3_Monitor1 = 5
+    UserOut4_Monitor2 = 6
+    PositionX = 7
+    PositionY = 8
+    PositionZ = 9
+    ModOutZ = 10
+    ModXControlSet = 11
+    ModYControlSet = 12
+    ModZControlSet = 13
+    ModZControlOutput = 14
 
-class InputSource(enum.Enum):
-    Deflection = enum.auto(),
-    Fast2_CX = enum.auto(),
-    Fast_User_CX = enum.auto(),
-    Friction = enum.auto(),
-    UserIn1 = enum.auto(),
-    UserIn2_UserB = enum.auto(),
-    UserIn3_UserA = enum.auto(),
-    UserIn4_CX = enum.auto(),
-    TipCurrent = enum.auto(),
-    TestGND_C3000 = enum.auto(),
-    TesRef_C3000 = enum.auto(),
-    TestMixedOut3_C3000 = enum.auto(),
-    AxisInX = enum.auto(),
-    AxisInY = enum.auto(),
-    AxisInZ = enum.auto(),
-    MainLockIn_Amplitude = enum.auto(),
-    MainPLL_FreqShift = enum.auto(),
-    ZControllerOut = enum.auto(),
-    InDetectorSum = enum.auto(),
-    In6 = enum.auto(),
-    CtrlX_Out = enum.auto(),
-    CtrlY_Out = enum.auto(),
-    CtrlW_Out = enum.auto(),
-    CtrlUser1_Out = enum.auto(),
-    CtrlUser2_Out = enum.auto(),
-    Analyzer1_CtrlDeltaF = enum.auto(),
-    Analyzer1_CtrlAmplitude = enum.auto(),
-    Analyzer1_Phase = enum.auto(),
-    Analyzer1_Amplitude = enum.auto(),
-    Analyzer1_X = enum.auto(),
-    Analyzer1_Y = enum.auto(),
+class InputSource(enum.IntEnum):
+    Deflection = 0
+    Fast2_CX = 1
+    Fast_User_CX = 2
+    Friction = 3
+    UserIn1 = 4
+    UserIn2_UserB = 5
+    UserIn3_UserA = 6
+    UserIn4_CX = 7
+    TipCurrent = 8
+    TestGND_C3000 = 9
+    TesRef_C3000 = 10
+    TestMixedOut3_C3000 = 11
+    AxisInX = 12
+    AxisInY = 13
+    AxisInZ = 14
+    MainLockIn_Amplitude = 15
+    MainPLL_FreqShift = 16
+    ZControllerOut = 17
+    InDetectorSum = 18
+    In6 = 19
+    CtrlX_Out = 20
+    CtrlY_Out = 21
+    CtrlW_Out = 22
+    CtrlUser1_Out = 23
+    CtrlUser2_Out = 24
+    Analyzer1_CtrlDeltaF = 25
+    Analyzer1_CtrlAmplitude = 26
+    Analyzer1_Phase = 27
+    Analyzer1_Amplitude = 28
+    Analyzer1_X = 29
+    Analyzer1_Y = 30
+    Ort_Baseline = 31
+    Ort_AmplitudeReduction = 32
+    Ort_Excitation = 33
     # Selections would make sense if the sweep could use another signal analyzer than number 2:
     # Analyzer2_CtrlDeltaF = enum.auto(),
     # Analyzer2_CtrlAmplitude = enum.auto(),
@@ -346,14 +349,11 @@ class InputSource(enum.Enum):
     # Analyzer2_Amplitude = enum.auto(),
     # Analyzer2_X = enum.auto(),
     # Analyzer2_Y = enum.auto(),
-    Ort_Baseline = enum.auto(),
-    Ort_AmplitudeReduction = enum.auto(),
-    Ort_Excitation = enum.auto(),
 
-class InputRanges(enum.Enum):
-    Full = enum.auto(),
-    OneOverFour = enum.auto(),
-    OneOverSixteen = enum.auto(),
+class InputRanges(enum.IntEnum):
+    Full = 0
+    OneOverFour = 1
+    OneOverSixteen = 2
 
 class Bandwidths(enum.IntEnum):
     Hz_23 = 0,
@@ -377,21 +377,21 @@ class FrequencySweep():
 
     # Output = enum.Enum('Output', {
     Output = {
-        FrequencySweepOutput.Normal_Excitation.name: _NormalExcitation,
-        FrequencySweepOutput.FastUser_OutB.name: _FastUser,
-        FrequencySweepOutput.TipVoltage_UserOutA.name: _TipVoltage,
-        FrequencySweepOutput.UserOut1_UserC.name: _OutUser1,
-        FrequencySweepOutput.UserOut2_UserA.name: _OutUser2,
-        FrequencySweepOutput.UserOut3_Monitor1.name: _OutUser3,
-        FrequencySweepOutput.UserOut4_Monitor2.name: _OutUser4,
-        FrequencySweepOutput.PositionX.name: _OutPositionX,
-        FrequencySweepOutput.PositionY.name: _OutPositionY,
-        FrequencySweepOutput.PositionZ.name: _OutPositionZ,
-        FrequencySweepOutput.ModOutZ.name: _ModOutZ,
-        FrequencySweepOutput.ModXControlSet.name: _ModXControlSet,
-        FrequencySweepOutput.ModYControlSet.name: _ModYControlSet,
-        FrequencySweepOutput.ModZControlSet.name: _ModZControlSet,
-        FrequencySweepOutput.ModZControlOutput.name: _ModZControlOutput
+        FrequencySweepOutput.Normal_Excitation: _NormalExcitation,
+        FrequencySweepOutput.FastUser_OutB: _FastUser,
+        FrequencySweepOutput.TipVoltage_UserOutA: _TipVoltage,
+        FrequencySweepOutput.UserOut1_UserC: _OutUser1,
+        FrequencySweepOutput.UserOut2_UserA: _OutUser2,
+        FrequencySweepOutput.UserOut3_Monitor1: _OutUser3,
+        FrequencySweepOutput.UserOut4_Monitor2: _OutUser4,
+        FrequencySweepOutput.PositionX: _OutPositionX,
+        FrequencySweepOutput.PositionY: _OutPositionY,
+        FrequencySweepOutput.PositionZ: _OutPositionZ,
+        FrequencySweepOutput.ModOutZ: _ModOutZ,
+        FrequencySweepOutput.ModXControlSet: _ModXControlSet,
+        FrequencySweepOutput.ModYControlSet: _ModYControlSet,
+        FrequencySweepOutput.ModZControlSet: _ModZControlSet,
+        FrequencySweepOutput.ModZControlOutput: _ModZControlOutput
         }
 
     input_sources_names: dict[InputSource, str] = {
@@ -662,7 +662,7 @@ class FrequencySweep():
         """Converts MixerBW enumeration to bandwidth in Hz."""
         mixer_base_filter_frequency = 11.1
         mixer_filter_step_factor = 2.0
-        return mixer_base_filter_frequency * mixer_filter_step_factor**mixer_bw_sel.value
+        return mixer_base_filter_frequency * mixer_filter_step_factor**mixer_bw_sel
 
     def start_execute(
             self, start_frequency: float, end_frequency: float, frequency_step: float,
@@ -711,7 +711,7 @@ class FrequencySweep():
         self._system_infra.main_in_2_gain.value = self.input_range_to_gain_map[input_range]
 
         # activate output for modulation
-        self.output_setup = self.Output[output.name](self._ll)
+        self.output_setup = self.Output[output](self._ll)
 
         self.measure_time = self._start(
             start_frequency, end_frequency, points, step_time, settle_time,
